import { format as d3Format } from 'd3-format';
import moment from 'moment';
export var DateFormatters;

(function (DateFormatters) {
  DateFormatters["Long"] = "LL";
  DateFormatters["Short"] = "ll";
  DateFormatters["Time"] = "LT";
  DateFormatters["DateTime"] = "LLL";
  DateFormatters["ISO8601"] = "YYYY-MM-DDTHH:mm:ssZ";
})(DateFormatters || (DateFormatters = {}));

export var formatDate = function formatDate(value, formatter) {
  return moment(value).format(formatter);
};
export var formatNumber = function formatNumber(value) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en-US';
  return Number(value).toLocaleString(locale);
};
export var formatCurrency = function formatCurrency(value) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en-US';
  var currency = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'USD';
  return Number(value).toLocaleString(locale, {
    style: 'currency',
    currency: currency
  });
};
/**
 * @param {Number} number
 * @param {Boolean} [includeDecimals]
 * @return {String}
 */

export var formatBytes = function formatBytes(number, includeDecimals) {
  return formatNumberForAnalytics(number, true, includeDecimals ? 2 : 0) // Add space between value and SI unit
  .replace(/([a-zA-Z]?)$/, ' $1') + 'B';
};
/**
 * @param {Number} number
 * @param {Boolean} [useSI]
 * @param {Number} [significantDecimals]
 * @param {Boolean} [trimInsignificantZeros]
 * @return {String}
 */

export var formatNumberForAnalytics = function formatNumberForAnalytics(number) {
  var useSI = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var significantDecimals = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;
  var trimInsignificantZeros = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
  var val = number;
  var suffix = ''; // Don't use SI units for sub-1 numbers (milli, micro, etc)

  if (useSI && number >= 1) {
    var siMatch = /^([^a-zA-Z]*)([a-zA-Z]?$)/.exec(d3Format('s')(number)); // split value from SI unit

    if (siMatch) {
      val = +siMatch[1];
      suffix = siMatch[2] || '';
    }
  }

  return d3Format(",.".concat(significantDecimals).concat(trimInsignificantZeros ? '~' : '', "f"))(val) + suffix;
};