"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.formatNumberForAnalytics = exports.formatBytes = exports.formatCurrency = exports.formatNumber = exports.formatDate = exports.DateFormatters = void 0;

var _d3Format = require("d3-format");

var _moment = _interopRequireDefault(require("moment"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var DateFormatters;
exports.DateFormatters = DateFormatters;

(function (DateFormatters) {
  DateFormatters["Long"] = "LL";
  DateFormatters["Short"] = "ll";
  DateFormatters["Time"] = "LT";
  DateFormatters["DateTime"] = "LLL";
  DateFormatters["ISO8601"] = "YYYY-MM-DDTHH:mm:ssZ";
})(DateFormatters || (exports.DateFormatters = DateFormatters = {}));

var formatDate = function formatDate(value, formatter) {
  return (0, _moment.default)(value).format(formatter);
};

exports.formatDate = formatDate;

var formatNumber = function formatNumber(value) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en-US';
  return Number(value).toLocaleString(locale);
};

exports.formatNumber = formatNumber;

var formatCurrency = function formatCurrency(value) {
  var locale = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'en-US';
  var currency = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 'USD';
  return Number(value).toLocaleString(locale, {
    style: 'currency',
    currency: currency
  });
};
/**
 * @param {Number} number
 * @param {Boolean} [includeDecimals]
 * @return {String}
 */


exports.formatCurrency = formatCurrency;

var formatBytes = function formatBytes(number, includeDecimals) {
  return formatNumberForAnalytics(number, true, includeDecimals ? 2 : 0) // Add space between value and SI unit
  .replace(/([a-zA-Z]?)$/, ' $1') + 'B';
};
/**
 * @param {Number} number
 * @param {Boolean} [useSI]
 * @param {Number} [significantDecimals]
 * @param {Boolean} [trimInsignificantZeros]
 * @return {String}
 */


exports.formatBytes = formatBytes;

var formatNumberForAnalytics = function formatNumberForAnalytics(number) {
  var useSI = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
  var significantDecimals = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 2;
  var trimInsignificantZeros = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : true;
  var val = number;
  var suffix = ''; // Don't use SI units for sub-1 numbers (milli, micro, etc)

  if (useSI && number >= 1) {
    var siMatch = /^([^a-zA-Z]*)([a-zA-Z]?$)/.exec((0, _d3Format.format)('s')(number)); // split value from SI unit

    if (siMatch) {
      val = +siMatch[1];
      suffix = siMatch[2] || '';
    }
  }

  return (0, _d3Format.format)(",.".concat(significantDecimals).concat(trimInsignificantZeros ? '~' : '', "f"))(val) + suffix;
};

exports.formatNumberForAnalytics = formatNumberForAnalytics;